#from . import genovi
#from addText import *
#from colors import *
#from create_raw import *
#from createConf import *
#from GC_analysis import *
#from genbank2faa import *
#from genbank2fna import *
#from mergeImages import *



# GenoVi is a pipeline that generates circular maps for bacterial (complete or non-complete)
# genomes using Circos software. It also allows the user to annotate COG classifications
# through DeepNOG predictions.
# 
# GenoVi is under a BY-NC-SA Creative Commons License, Please cite. Cumsille et al., 2021
# You may remix, tweak, and build upon this work even for commercial purposes, as long as
# you credit this work and license your new creations under the identical terms.
# 
# Developed by Andres Cumsille, Andrea Rodriguez, Roberto E. Duran & Vicente Saona Urmeneta
# For any code related query, contact: andrea.rodriguezdelherbe@rdm.ox.ac.uk, vicente.saona@sansano.usm.cl.
#
# This file contains a command-line utility for calculating the GC percentage and GC skew of a genomic
# sequence. Based on Jennifer Lu's (jennifer.lu717@gmail.com) SkewIt and GC_analysis utility.

import argparse as ap
import sys
from Bio import SeqIO

# Parse user arguments
def get_args():
    parser = ap.ArgumentParser()
    requiredNamed = parser.add_argument_group('required named arguments')
    requiredNamed.add_argument("-i", "--input_file", type=str, help="Name of the input file in FASTA format",
                               required=True)
    requiredNamed.add_argument("-w", "--window_size", type=int,
                               help="Number of base pairs where the GC percentage is calculated for",
                               default=1000)
    requiredNamed.add_argument("-s", "--shift", type=int, help="The shift increment. Defaults to window size", default=-1)
    parser.add_argument("-o", "--output_file", type=str, help="Name of the output files. Defaults to match input file.", default = " ")
    parser.add_argument("-ot", "--omit_tail", action="store_true", help="True: if the trailing sequence should be "
                                                                        "omitted. Default behaviour is to retain "
                                                                        "the leftover sequence.",
                        default=False)
    parser.add_argument("-f", "--output_format", type=str, choices=["wiggle"],
                        default="wiggle")
    args = parser.parse_args()
    
    return args.input_file, args.output_file, args.window_size, args.shift, args.omit_tail, args.output_format

# Writes final locations to output file
def write_content(loc, final_loc, data, file):
    file.write("chr" + str(globalIndex)
               + "\t" + str(loc + 1) + "\t" + str(final_loc) + "\t" + str(data) + "\n")

# Calculating GC content and GC skew
def generate_result():
    """
    Calculate GC percentage and write to output file.
    :return: None
    """
    seq_len = len(record)  # Get length of sequence
    i=0
    global max_GC_percentage
    global min_GC_percentage
    global maxSkew
    global minSkew
    i = -1
    for i in range((seq_len - window_size + shift) // shift):  # Iterate over the total number of shifts
        frag = record.seq[i * shift: i * shift + window_size]  # Extract the string for counting
        # Count number of C and G and convert to percentage
        percent = int(round((frag.count("C") + frag.count("G")) / float(window_size) * 100))
        g = float(frag.count("G"))
        c = float(frag.count("C"))
        if (g+c) > 0:
            new_calc = (g-c)/(g+c)
        else:
            new_calc = 0.0
        if(percent > max_GC_percentage): 
            max_GC_percentage = percent
        if(percent < min_GC_percentage):
            min_GC_percentage = percent
        if(new_calc > maxSkew): 
            maxSkew = new_calc
        if(new_calc < minSkew):
            minSkew = new_calc
        write_content(sequence_begin + i * shift, sequence_begin + i * shift + window_size, percent, result_content)
        write_content(sequence_begin + i * shift, sequence_begin + i * shift + window_size, new_calc, result_skew)
    if (i + 1) * shift < seq_len and not omit_tail:
        # if trailing sequence exits and omit_tail is False
        frag = record.seq[(i + 1) * shift:]
        percent = int(round((frag.count("C") + frag.count("G")) / float(len(frag)) * 100))
        g = float(frag.count("G"))
        c = float(frag.count("C"))
        if (g+c) > 0:
            new_calc = (g-c)/(g+c)
        else:
            new_calc = 0.0
        if(percent > max_GC_percentage): 
            max_GC_percentage = percent
        if(percent < min_GC_percentage):
            min_GC_percentage = percent
        if(new_calc > maxSkew): 
            maxSkew = new_calc
        if(new_calc < minSkew):
            minSkew = new_calc
        write_content(sequence_begin + (i + 1) * shift, sequence_begin + seq_len, percent, result_content)
        write_content(sequence_begin + (i + 1) * shift, sequence_begin + seq_len, new_calc, result_skew)
    return(seq_len)

# Starting from a .fna FASTA file, generates files with GC content and GC skew.
# Input: FASTA filename
def makeGC(input_file, output_file = " ", w_size = 5000, s = -1, o_t = False, o_f = "wiggle"):
    if(output_file == " "):
        output_file = input_file
    global window_size, shift, omit_tail, output_format, sequence_begin, result_skew, result_content, record, globalIndex, max_GC_percentage, min_GC_percentage, minSkew, maxSkew
    window_size = w_size
    shift = s if s!= -1 else window_size
    omit_tail = o_t
    output_format = o_f
    records = SeqIO.index(input_file, "fasta")
    records_num = len(records)
    sequence_begin = 0
    min_GC_percentage = 101
    max_GC_percentage = -1
    maxSkew = -float("inf")
    minSkew = float("inf")
    file = open(output_file + "_GC_content.wig", "w+")
    file2 = open(output_file + "_GC_skew.wig", "w+")
    file.close()
    file2.close()
    if records_num < 1:
        # No sequence in fasta file, corrupted
        sys.stdout.write("WARNING! {} contains no sequence data.\n".format(input_file))
        raise TypeError
    else:
        result_content = open(output_file + "_GC_content.wig", "a+")
        result_skew = open(output_file + "_GC_skew.wig", "a+")
        globalIndex = 1
        for record in SeqIO.parse(input_file, "fasta"):
            sequence_begin += generate_result()
            globalIndex += 1
        result_content.close()
        result_skew.close()
        if __name__ == "__main__":
            file = open(output_file + ".maxmin", "w")
            file.write("#Plot GC content\nmin = {}\nmax = {}\n\n#Plot GC skew\nmin = {}\nmax = {}".format(min_GC_percentage, max_GC_percentage, minSkew, maxSkew))
            file.close()
        else:
            return {"min_GC_content": min_GC_percentage,
                    "max_GC_content": max_GC_percentage,
                    "min_skew": minSkew,
                    "max_skew": maxSkew
            }

if __name__ == "__main__":
    makeGC(*get_args())
    



# GenoVi is a pipeline that generates circular maps for bacterial (complete or non-complete)
# genomes using Circos software. It also allows the user to annotate COG classifications
# through DeepNOG predictions.
# 
# GenoVi is under a BY-NC-SA Creative Commons License, Please cite. Cumsille et al., 2021
# You may remix, tweak, and build upon this work even for commercial purposes, as long as
# you credit this work and license your new creations under the identical terms.
# 
# Developed by Andres Cumsille, Andrea Rodriguez, Roberto E. Duran & Vicente Saona Urmeneta
# For any code related query, contact: andrea.rodriguezdelherbe@rdm.ox.ac.uk, vicente.saona@sansano.usm.cl.
#
# This file defines an utility for transforming GenBank flat files into .faa FASTA files.
# Intended for GenoVi usage, might not work in other cases.

from Bio import SeqIO
import argparse
import re

# Modifies locus description in case that input file was generated
# with Prokka.
def modify_locus(input):
    input_handle  = open(input, "r")
    line = input_handle.readline()
    locus = ""
    locuses = []
    old = []
    while line:  
        if "LOCUS" in line:
            locus = line[:-1]
            old.append(locus)
            date = input_handle.readline()
            locus = locus + "   " + date
        elif "     source" in line:
            size = line.split("          ")[-1].split("..")[-1][:-1]
            if size in locus:
                aux = locus.split(size + " ")
                new_locus = aux[0] + "  " + size + " " + aux[1]
                locuses.append(new_locus)
        line = input_handle.readline()
    input_handle.close()
    
    input_modify  = open(input, "r")
    for i in range(len(locuses)):
        if i == 0:
            fileContent = re.sub(old[i], locuses[i], input_modify.read())
        else:
            fileContent = re.sub(old[i], locuses[i], fileContent)

    input_modify.close()
    input_modify = open(input, "w")
    input_modify.write(fileContent)
    input_modify.close()
    input_modify = open(input, "r")
        
# Function that transforms genbank file to faa file.   
def genbankToFaa(input, output, verbose = False):
    try:
        input_handle  = open(input, "r")
    except:
        input = input + ".gbk"
        input_handle  = open(input, "r")
    output_handle = open(output, "w")

    line = input_handle.readline()
    input_handle.close()
    if not line.split(' bp ')[-2].split(' ')[-1].isdecimal():
        modify_locus(input)
        
      
    for seq_record in SeqIO.parse(open(input,"r"), "genbank"):
        if verbose:
            print("Dealing with GenBank record %s" % seq_record.id)
        for seq_feature in seq_record.features :
            if seq_feature.type=="CDS":
                if "translation" in seq_feature.qualifiers and len(seq_feature.qualifiers['translation'])==1:
                    fasta = seq_feature.qualifiers['translation'][0]
                    output_handle.write(">%s from %s\n%s\n" % (
                        seq_feature.qualifiers['locus_tag'][0],
                        seq_record.name,
                        "\n".join([fasta[i:i+60] for i in range(0, len(fasta), 60)])))

    output_handle.close()
    input_handle.close()
    if verbose:
        print("Done")

if __name__ == "__main__":
    parser = argparse.ArgumentParser(description="Starting from a GenBank flat file, this simplifies it as a .fna")
    parser.add_argument("inputFile", help="flat file to be translated")
    parser.add_argument("--outputFile", help="output file name" )
    args = parser.parse_args()
    if ".gb" in args.inputFile:
        if args.inputFile[-4] == ".":
            args.inputFile = args.inputFile[:-4]
        elif args.inputFile[-3] == ".":
            args.inputFile = args.inputFile[:-3]
    if args.outputFile is None:
        args.outputFile = args.inputFile + "_converted.faa"
    genbankToFaa(args.inputFile, args.outputFile)



from setuptools import setup, find_packages

extra_test = [
  'pytest>=4',
  'pytest-cov>=2',
],
	
extra_dev = [
  *extra_test,
]

extra_ci = [
  *extra_test,
  'python-coveralls',
]

setup(
  name = 'genovi',         # How you named your package folder (MyLib)
  packages = find_packages(),   # Chose the same as "name"
  version = '0.1.7',      # Start with a small number and increase it with every change you make
  license='BY-NC-SA Creative Commons License',        # Chose a license from here: https://help.github.com/articles/licensing-a-repository
  description = 'Generates full genome images from a gbff file',   # Give a short description about your library
  author = 'Cumsille A. et al.',                   # Type in your name
  author_email = 'andrea.rodriguez.12@sansano.usm.cl',      # Type in your E-Mail
  url = 'https://github.com/robotoD/GenoVi',   # Provide either the link to your github or to your website
  download_url = 'https://github.com/robotoD/GenoVi/archive/refs/tags/0.1.6.tar.gz',    # I explain this later on
  keywords = ['bioinformatics', 'genomics', 'CIRCOS'],   # Keywords that define your package best
  install_requires=[            # I get to this in a second
          'cairosvg',
          'numpy',
          'pandas',
          'BioPython',
          'argparse',
          'deepnog==1.2.3'
      ],
  classifiers=[
    'Development Status :: 3 - Alpha',      # Chose either "3 - Alpha", "4 - Beta" or "5 - Production/Stable" as the current state of your package
    'Intended Audience :: Science/Research',
    'Topic :: Scientific/Engineering :: Visualization',
    'Topic :: Scientific/Engineering :: Bio-Informatics',
    'License :: OSI Approved :: MIT License',   # Again, pick a license
    'Programming Language :: Python :: 3.7',
    'Programming Language :: Python :: 3.8',
    'Programming Language :: Python :: 3.9',
    'Programming Language :: Python :: 3.10',
    'Programming Language :: Python :: 3.11',
    'Natural Language :: English',
    
  ],
  entry_points = {
              'console_scripts': [
                  'genovi=GenoVi:main',                   
              ],              
          },
  
  extras_require={
    'test': extra_test,
    'dev': extra_dev,
  },

  
)



#!/usr/bin/python

# GenoVi is a pipeline that generates circular maps for bacterial (complete or non-complete)
# genomes using Circos software. It also allows the user to annotate COG classifications
# through DeepNOG predictions.
# 
# GenoVi is under a BY-NC-SA Creative Commons License, Please cite. Cumsille et al., 2021
# You may remix, tweak, and build upon this work even for commercial purposes, as long as
# you credit this work and license your new creations under the identical terms.
# 
# Developed by Andres Cumsille, Andrea Rodriguez, Roberto E. Duran & Vicente Saona Urmeneta
# For any code related query, contact: andrea.rodriguezdelherbe@rdm.ox.ac.uk, vicente.saona@sansano.usm.cl.

import scripts.create_raw as create_raw
import scripts.GC_analysis as GC_analysis
import scripts.genbank2fna as gbk2fna
import scripts.genbank2faa as genbank2faa
import scripts.createConf as createConf
import scripts.addText as addText
import scripts.mergeImages as merge
import scripts.colors as colors

import re
import argparse as ap
import os
from shutil import which

try:
    from cairosvg import svg2png
    cairo = True
except:
    cairo = False
    # print("There's been an error finding cairoSVG library, so PNG images might be different from expected. Please prefer using SVG output.")

# Changes background color to a white Circos-generated svg image (modifies original file)
# input: Final color
def change_background(color, fileName = "circos.svg"):
    file = open(fileName)
    outFile = open("Genovi_temp_file.svg", "w")
    for line in file:
        if re.match('<rect x="-?1?0?0?0" y="0" width="[345]000px" height="3000px" style="fill:rgb\(255,255,255\);"/>',line):
            outFile.write('<rect x="-1000" y="-1000" width="5000px" height="5000px" style="fill:{};"/>'.format(color))
        else:
            outFile.write(line)
    if os.remove(fileName):
        raise RuntimeError("Theres been an error deleting a temporary file")
    if os.rename("Genovi_temp_file.svg", fileName):
        raise RuntimeError("Theres been an error deleting a temporary file")

# Full pipeline
# input: anotated genome filename.
def visualizeGenome(input_file, output_file = "circos", 
                    cogs_unclassified = True, deepnog_confidence_threshold = 0, separate_circles = False, alignment = "center", scale = "variable", keep_temporary_files = False, window = 5000, verbose = False,
                    captions = True, captionsPosition = "auto", title = "", title_position = "center", italic_words = 2, size = False,
                    color_scheme = "auto", background_color = "transparent", font_color = "0, 0, 0", GC_content = "auto", GC_skew ='auto', tRNA = 'auto', rRNA = 'auto', CDS_positive = 'auto', CDS_negative = 'auto', skew_line_color = '0, 0, 0'):
        
    
    if not cairo:
        print("There's been an error finding cairoSVG library, so PNG images might be different from expected. Please prefer using SVG output.")
    if output_file[-4:] == ".svg" or output_file[-4:] == ".png":
        output_file = output_file[:-4]
    if deepnog_confidence_threshold > 1 or deepnog_confidence_threshold < 0:
        if verbose:
            print("DeepNOG lower bound must be between 0 and 1")
        raise Exception("DeepNOG lower bound must be between 0 and 1")

    if which("circos") == None:
        if verbose:
            print("Circos is not installed. please install for using GenoVi.")
        raise Exception("Circos is not installed. please install for using GenoVi.")
    
    color_scheme, background_color, GC_content, GC_skew, tRNA, rRNA, CDS_positive, CDS_negative, skew_line_color = colors.parseColors(color_scheme, background_color, GC_content, GC_skew, tRNA, rRNA, CDS_positive, CDS_negative, skew_line_color)
    delete_background = False
    if background_color == "transparent" or background_color == "none" or background_color == "auto":
        delete_background = True
        background_color = "white"
    
    if not os.path.exists("temp"):
        os.mkdir("temp")
    if separate_circles:
        file = open(input_file)
        contigs = file.read().split("\n//\n")
        file.close()
        if len(contigs[-1]) < 20:   # If file ends with "//"
            contigs = contigs[:-1]
        for i in range(1, len(contigs) + 1):
            contigFile = open("temp/" + str(i) + ".gbk", "w")
            contigFile.write(contigs[i - 1])
            contigFile.close()
        
        images = []
        full_cogs = set([])
        for i in range(1, len(contigs) + 1):
            file = "temp/" + str(i) + ".gbk"
            sizes, cogs_p, cogs_n = create_raw.base(file, "temp/", True, True, cogs_unclassified, cogs_unclassified, False, True, deepnog_confidence_threshold, verbose)
            full_cogs = full_cogs.union(cogs_p).union(cogs_n)
            images.append({"size": sizes[0], "fileName": output_file + "-contig_" + str(i) + ".svg"})
            gbk2fna.gbkToFna(file, "temp/gbk_converted.fna", verbose)
            maxmins = GC_analysis.makeGC("temp/gbk_converted.fna", "temp/GC", window)
            createConf.create_conf(maxmins, font_color, GC_content, GC_skew, CDS_positive, CDS_negative, tRNA, rRNA, skew_line_color, background_color, cogs_unclassified, cogs_p, cogs_n)
            
            if verbose:
                print("Drawing {}...".format(i))
            os.system("circos circos.conf >/dev/null 2>&1")
            os.system("circos -debug_group _all >/dev/null 2>&1")
            if delete_background:
                change_background("none")
                if cairo:
                    if verbose:
                        print("Converting to png...")
                    svgFile = open("circos.svg")
                    svg2png(bytestring = svgFile.read(), write_to = output_file + ".png")
                    
                    svgFile.close()

            if size:
                addText.addText("", "center", "circos.svg", "circ_v.svg", captions = False, cogs_captions = False, size = sizes[0], font_color = font_color)
                os.rename("circ_v.svg", output_file + "-contig_" + str(i) + ".svg")
            else:
                os.rename("circos.svg", output_file + "-contig_" + str(i) + ".svg")
            os.rename("circos.png", output_file + "-contig_" + str(i) + ".png")
            if cogs_unclassified:
                os.rename("temp/_prediction_deepnog.csv", "temp/" + str(i) + "_prediction_deepnog.csv")
            for file_i in os.listdir("temp/"):
                if ".gbk" not in file_i and ".csv" not in file_i and not "contig-" in file_i:
                    os.rename("temp/" + file_i, "temp/contig-" + str(i) + "-" + file_i)
            os.remove(file)

        if captions or title != "":
            if captionsPosition == "auto":
                captionsPosition = "top-right" if alignment == "bottom" else "bottom-right"
            if title_position == "center":
                addText.addText(title, position = title_position, inFile = output_file + "-contig_" + "1.svg", italic = italic_words, captions = False, font_color = font_color)
                os.remove(output_file + "-contig_" + "1.svg")
                os.rename("titled_" + output_file + "-contig_" + "1.svg", output_file + "-contig_" + "1.svg")
                merge.mergeImages(images, outFile = output_file + ".svg", align = alignment, scale = scale, background_color = "none" if delete_background else background_color)
                addText.addText("", inFile = output_file + ".svg", captions = captions, cogs_captions = cogs_unclassified, captionsPosition = captionsPosition, cogs = full_cogs,
                                pCDS_color = CDS_positive, nCDS_color = CDS_negative, tRNA_color = tRNA, rRNA_color = rRNA, GC_content_color = GC_content, font_color = font_color)
            else:
                merge.mergeImages(images, outFile = output_file + ".svg", align = alignment, scale = scale, background_color = "none" if delete_background else background_color)
                addText.addText(title, position = title_position, inFile = output_file + ".svg", italic = italic_words, captions = captions, cogs_captions = cogs_unclassified, captionsPosition = captionsPosition, cogs = full_cogs,
                                pCDS_color = CDS_positive, nCDS_color = CDS_negative, tRNA_color = tRNA, rRNA_color = rRNA, GC_content_color = GC_content, font_color = font_color)
            os.remove(output_file + ".svg")
            os.rename("titled_" + output_file + ".svg", output_file + ".svg")
        else:
            merge.mergeImages(images, outFile = output_file + ".svg", align = alignment, scale = scale, background_color = "none" if delete_background else background_color)
        if not os.path.exists(output_file):
            os.mkdir(output_file)
        for i in range(1, len(contigs) + 1):
            os.rename(output_file + "-contig_" + str(i) + ".svg", output_file + "/" + output_file + "-contig_" + str(i) + ".svg")
            os.rename(output_file + "-contig_" + str(i) + ".png", output_file + "/" + output_file + "-contig_" + str(i) + ".png")
    else:
        sizes, cogs_p, cogs_n = create_raw.base(input_file, "temp/", True, True, cogs_unclassified, cogs_unclassified, False, True, deepnog_confidence_threshold, verbose)
        cogs_p = set(map(lambda x : "None" if x == None else x[0], cogs_p))
        cogs_n = set(map(lambda x : "None" if x == None else x[0], cogs_n))
        
        gbk2fna.gbkToFna(input_file, "temp/gbk_converted.fna", verbose)
        maxmins = GC_analysis.makeGC("temp/gbk_converted.fna", "temp/GC", window)
        createConf.create_conf(maxmins, font_color, GC_content, GC_skew, CDS_positive, CDS_negative, tRNA, rRNA, skew_line_color, background_color, cogs_unclassified, cogs_p, cogs_n)

        if verbose:
            print("Drawing...")
        if which("circos") == None:
            if verbose:
                print("Circos is not installed. please install for using this program.")
            raise(Exception)
        os.system("circos circos.conf >/dev/null 2>&1")
        os.system("circos -debug_group _all >/dev/null 2>&1")
        if delete_background:
            change_background("none")
        if captions or title != "" or size:
            captionsPosition = "bottom-right" if captionsPosition == "auto" else captionsPosition
            addText.addText(title, position = title_position, inFile = "circos.svg", italic = italic_words, captions = captions, cogs_captions = cogs_unclassified, captionsPosition = captionsPosition, cogs = cogs_p.union(cogs_n),
            pCDS_color = CDS_positive, nCDS_color = CDS_negative, tRNA_color = tRNA, rRNA_color = rRNA, GC_content_color = GC_content, font_color = font_color, size = sizes[0] if size else "")
            os.remove("circos.svg")
            os.rename("titled_circos.svg", "circos.svg")
    if cairo:
        if verbose:
            print("Converting to png...")
        file = open("circos.svg")
        svg2png(bytestring = file.read(), write_to = output_file + ".png")
        file.close()
    os.rename("circos.svg", output_file + ".svg")
    if output_file != "circos":
        os.remove("circos.png")

    if not keep_temporary_files:
        if verbose:
            print("deleting temporary files")
        os.remove("circos.conf")
        for file in os.listdir("temp/"):
            os.remove("temp/" + file)
        for file in os.listdir("conf/"):
            os.remove("conf/" + file)
        os.rmdir("temp")
        os.rmdir("conf")
    
# Parse user arguments
def get_args():
    parser = ap.ArgumentParser()
    parser.add_argument("-i", "--input_file", type=str, help="Genbank file path", required=True)
    parser.add_argument("-o", "--output_file", type=str, help="Output image file path. Default: circos", default = "circos")
    parser.add_argument("-cu", "--cogs_unclassified", action='store_false', help="Do not clasify each coding sequence and draw them by color.", required = False)
    parser.add_argument("-b", "--deepnog_confidence_threshold", type=float, help="Lower bound for DeepNOG prediction certainty to be considered. Values in range [0,1] Default: 0", default = 0)
    parser.add_argument("-s", "--separate_circles", action='store_true', help="To draw each contig as a complete circle by itself.", required = False)
    parser.add_argument("-a", "--alignment", type=str, choices=["center", "top", "bottom", "A", "<", "U"], help="When using --separate_circles, this defines the vertical alignment of every contig. Options: center, top, bottom, A (First on top), < (first to the left), U (Two on top, the rest below). By default this is defined by contig sizes", default = "auto")
    parser.add_argument("--scale", type=str, choices=["variable", "linear", "sqrt"], help="When using --separate_circles, wether to use a different scale for tiny contigs, so to ensure visibility. Options: variable, linear, sqrt. Default: sqrt", default = "sqrt")
    parser.add_argument("-k", "--keep_temporary_files", action='store_true', help="Don't delete files used for circos image generation, including protein categories prediction by Deepnog.", required = False)
    parser.add_argument("-w", "--window", "--step", type=int, help="base pair window for CG plotting. Default: 5000", default = 5000)
    parser.add_argument("-v", "--verbose", type=bool, help="Wether to print progress logs.", default = True)

    text_group = parser.add_argument_group("text")
    text_group.add_argument("-c", "--captions_not_included", action='store_false', help = "Do not include color explanation.", required = False)
    #text_group.add_argument("-cp", "--captions_position", type=str, choices=["variable", "linear", "sqrt"], help="When using --separate_circles, wether to use a different scale for tiny contigs, so to ensure visibility. Options: variable, linear, sqrt. Default: sqrt", default = "sqrt")
    text_group.add_argument("-cp", "--captions_position", type=str, choices=["right", "left", "auto"], help = "Where to insert color explanation. Options: left, right, auto.", default = "auto")
    text_group.add_argument("-t", "--title", type=str, help="Title of the image (strain name, or something like that). By default, it doesn't include title", default = "")
    text_group.add_argument("--title_position", type=str, choices=["center", "top", "bottom"], default = "center")
    text_group.add_argument("--italic_words", type=int, help="How many of the title's words should be written in italics. Default: 2", default = 2)
    text_group.add_argument("--size", action='store_true', help="To write the size (in base pairs) in each circle.", required = False)

    color_group = parser.add_argument_group("colors")
    color_group.add_argument("-cs", "--color_scheme", "--color", type=str, help='''Color scheme to use. Individual colors may be overriden wih other arguments. COGs' coloring can't be changed.
                                Options: neutral, blue, purple, soil, grayscale, velvet, pastel, ocean, wood, beach, desert, ice, island, forest, toxic, fire, spring''', default = 'auto')
    color_group.add_argument("-bc", "--background", "--background_color", type=str, help="Color for background. Default: transparent", default = 'transparent')
    color_group.add_argument("-fc", "--font_color", type=str, help="Color for ticks and caption texts. Default: black", default = '0, 0, 0')
    color_group.add_argument("-pc", "--CDS_positive_color", type=str, help="Color for positive CDSs, in R, G, B format. Default: '180, 205, 222'", default = 'auto')
    color_group.add_argument("-nc", "--CDS_negative_color", type=str, help="Color for negative CDSs, in R, G, B format. Default: '53, 176, 42'", default = 'auto')
    color_group.add_argument("-tc", "--tRNA_color", type=str, help="Color for tRNAs, in R, G, B format. Default: '150, 5, 50'", default = 'auto')
    color_group.add_argument("-rc", "--rRNA_color", type=str, help="Color for rRNAs, in R, G, B format. Default: '150, 150, 50'", default = 'auto')
    color_group.add_argument("-cc", "--GC_content_color", type=str, help="Color for GC content, in R, G, B format. Default: '23, 0, 115'", default = "auto")
    color_group.add_argument("-sc", "--GC_skew_color", type=str, help="Color scheme for GC skew. Might be a pair of RGB colors or Circos-understandable code. For details on this, please read CIRCOS documentation. Default: '140, 150, 198 - 158, 188, 218'", default = 'auto')
    color_group.add_argument("-sl", "--GC_skew_line_color", type=str, help="Color for GC skew line. Default: black", default = 'auto')
    

    args = parser.parse_args()

    return (args.input_file, args.output_file,
    args.cogs_unclassified, args.deepnog_confidence_threshold, args.separate_circles, args.alignment, args.scale, args.keep_temporary_files, args.window, args.verbose,
    args.captions_not_included, args.captions_position, args.title, args.title_position, args.italic_words, args.size, 
    args.color_scheme, args.background, args.font_color, args.GC_content_color, args.GC_skew_color, args.tRNA_color, args.rRNA_color, args.CDS_positive_color, args.CDS_negative_color, args.GC_skew_line_color)

def main():
	visualizeGenome(*get_args())


if __name__ == "__main__":
    visualizeGenome(*get_args())
